#include "testlib.h"
#include <stdio.h>
#include <iostream>
#include <stdlib.h>
#include <string>
#include <string.h>
#include <vector>
#include <stack>
#include <queue>
#include <deque>
#include <set>
#include <map>
#include <assert.h>
#include <algorithm>
#include <iomanip>
#include <time.h>
#include <math.h>
#include <bitset>
#include <complex>

#pragma comment(linker, "/STACK:256000000")

using namespace std;

typedef long long int ll;
typedef long double ld;

const int INF = 1000 * 1000 * 1000 + 21;
const ll LLINF = (1ll << 60) + 5;
const int MOD = 1000 * 1000 * 1000 + 7;

const int base = 1000000000;
const int base_digits = 9;
const double PI = 3.14159265358979323846;

struct bigint {
  vector<int> z;
  int sign;

  bigint() :
    sign(1) {
  }

  bigint(long long v) {
    *this = v;
  }

  bigint(const string &s) {
    read(s);
  }

  void operator=(const bigint &v) {
    sign = v.sign;
    z = v.z;
  }

  void operator=(long long v) {
    sign = 1;
    if (v < 0)
      sign = -1, v = -v;
    z.clear();
    for (; v > 0; v = v / base)
      z.push_back(v % base);
  }

  bigint operator+(const bigint &v) const {
    if (sign == v.sign) {
      bigint res = v;

      for (int i = 0, carry = 0; i < (int)max(z.size(), v.z.size()) || carry; ++i) {
        if (i == (int)res.z.size())
          res.z.push_back(0);
        res.z[i] += carry + (i < (int)z.size() ? z[i] : 0);
        carry = res.z[i] >= base;
        if (carry)
          res.z[i] -= base;
      }
      return res;
    }
    return *this - (-v);
  }

  bigint operator-(const bigint &v) const {
    if (sign == v.sign) {
      if (abs() >= v.abs()) {
        bigint res = *this;
        for (int i = 0, carry = 0; i < (int)v.z.size() || carry; ++i) {
          res.z[i] -= carry + (i < (int)v.z.size() ? v.z[i] : 0);
          carry = res.z[i] < 0;
          if (carry)
            res.z[i] += base;
        }
        res.trim();
        return res;
      }
      return -(v - *this);
    }
    return *this + (-v);
  }

  void operator*=(int v) {
    if (v < 0)
      sign = -sign, v = -v;
    for (int i = 0, carry = 0; i < (int)z.size() || carry; ++i) {
      if (i == (int)z.size())
        z.push_back(0);
      long long cur = z[i] * (long long)v + carry;
      carry = (int)(cur / base);
      z[i] = (int)(cur % base);
      //asm("divl %%ecx" : "=a"(carry), "=d"(a[i]) : "A"(cur), "c"(base));
    }
    trim();
  }

  bigint operator*(int v) const {
    bigint res = *this;
    res *= v;
    return res;
  }

  friend pair<bigint, bigint> divmod(const bigint &a1, const bigint &b1) {
    int norm = base / (b1.z.back() + 1);
    bigint a = a1.abs() * norm;
    bigint b = b1.abs() * norm;
    bigint q, r;
    q.z.resize(a.z.size());

    for (int i = a.z.size() - 1; i >= 0; i--) {
      r *= base;
      r += a.z[i];
      int s1 = b.z.size() < r.z.size() ? r.z[b.z.size()] : 0;
      int s2 = b.z.size() - 1 < r.z.size() ? r.z[b.z.size() - 1] : 0;
      int d = ((long long)s1 * base + s2) / b.z.back();
      r -= b * d;
      while (r < 0)
        r += b, --d;
      q.z[i] = d;
    }

    q.sign = a1.sign * b1.sign;
    r.sign = a1.sign;
    q.trim();
    r.trim();
    return make_pair(q, r / norm);
  }

  friend bigint sqrt(const bigint &a1) {
    bigint a = a1;
    while (a.z.empty() || a.z.size() % 2 == 1)
      a.z.push_back(0);

    int n = a.z.size();

    int firstDigit = (int)sqrt((double)a.z[n - 1] * base + a.z[n - 2]);
    int norm = base / (firstDigit + 1);
    a *= norm;
    a *= norm;
    while (a.z.empty() || a.z.size() % 2 == 1)
      a.z.push_back(0);

    bigint r = (long long)a.z[n - 1] * base + a.z[n - 2];
    firstDigit = (int)sqrt((double)a.z[n - 1] * base + a.z[n - 2]);
    int q = firstDigit;
    bigint res;

    for (int j = n / 2 - 1; j >= 0; j--) {
      for (;; --q) {
        bigint r1 = (r - (res * 2 * base + q) * q) * base * base + (j > 0 ? (long long)a.z[2 * j - 1] * base + a.z[2 * j - 2] : 0);
        if (r1 >= 0) {
          r = r1;
          break;
        }
      }
      res *= base;
      res += q;

      if (j > 0) {
        int d1 = res.z.size() + 2 < r.z.size() ? r.z[res.z.size() + 2] : 0;
        int d2 = res.z.size() + 1 < r.z.size() ? r.z[res.z.size() + 1] : 0;
        int d3 = res.z.size() < r.z.size() ? r.z[res.z.size()] : 0;
        q = ((long long)d1 * base * base + (long long)d2 * base + d3) / (firstDigit * 2);
      }
    }

    res.trim();
    return res / norm;
  }

  bigint operator/(const bigint &v) const {
    return divmod(*this, v).first;
  }

  bigint operator%(const bigint &v) const {
    return divmod(*this, v).second;
  }

  void operator/=(int v) {
    if (v < 0)
      sign = -sign, v = -v;
    for (int i = (int)z.size() - 1, rem = 0; i >= 0; --i) {
      long long cur = z[i] + rem * (long long)base;
      z[i] = (int)(cur / v);
      rem = (int)(cur % v);
    }
    trim();
  }

  bigint operator/(int v) const {
    bigint res = *this;
    res /= v;
    return res;
  }

  int operator%(int v) const {
    if (v < 0)
      v = -v;
    int m = 0;
    for (int i = z.size() - 1; i >= 0; --i)
      m = (z[i] + m * (long long)base) % v;
    return m * sign;
  }

  void operator+=(const bigint &v) {
    *this = *this + v;
  }
  void operator-=(const bigint &v) {
    *this = *this - v;
  }
  void operator*=(const bigint &v) {
    *this = *this * v;
  }
  void operator/=(const bigint &v) {
    *this = *this / v;
  }

  bool operator<(const bigint &v) const {
    if (sign != v.sign)
      return sign < v.sign;
    if (z.size() != v.z.size())
      return z.size() * sign < v.z.size() * v.sign;
    for (int i = z.size() - 1; i >= 0; i--)
      if (z[i] != v.z[i])
        return z[i] * sign < v.z[i] * sign;
    return false;
  }

  bool operator>(const bigint &v) const {
    return v < *this;
  }
  bool operator<=(const bigint &v) const {
    return !(v < *this);
  }
  bool operator>=(const bigint &v) const {
    return !(*this < v);
  }
  bool operator==(const bigint &v) const {
    return !(*this < v) && !(v < *this);
  }
  bool operator!=(const bigint &v) const {
    return *this < v || v < *this;
  }

  void trim() {
    while (!z.empty() && z.back() == 0)
      z.pop_back();
    if (z.empty())
      sign = 1;
  }

  bool isZero() const {
    return z.empty() || (z.size() == 1 && !z[0]);
  }

  bigint operator-() const {
    bigint res = *this;
    res.sign = -sign;
    return res;
  }

  bigint abs() const {
    bigint res = *this;
    res.sign *= res.sign;
    return res;
  }

  long long longValue() const {
    long long res = 0;
    for (int i = z.size() - 1; i >= 0; i--)
      res = res * base + z[i];
    return res * sign;
  }

  friend bigint gcd(const bigint &a, const bigint &b) {
    return b.isZero() ? a : gcd(b, a % b);
  }
  friend bigint lcm(const bigint &a, const bigint &b) {
    return a / gcd(a, b) * b;
  }

  void read(const string &s) {
    sign = 1;
    z.clear();
    int pos = 0;
    while (pos < (int)s.size() && (s[pos] == '-' || s[pos] == '+')) {
      if (s[pos] == '-')
        sign = -sign;
      ++pos;
    }
    for (int i = s.size() - 1; i >= pos; i -= base_digits) {
      int x = 0;
      for (int j = max(pos, i - base_digits + 1); j <= i; j++)
        x = x * 10 + s[j] - '0';
      z.push_back(x);
    }
    trim();
  }

  friend istream& operator>>(istream &stream, bigint &v) {
    string s;
    stream >> s;
    v.read(s);
    return stream;
  }

  friend ostream& operator<<(ostream &stream, const bigint &v) {
    if (v.sign == -1)
      stream << '-';
    stream << (v.z.empty() ? 0 : v.z.back());
    for (int i = (int)v.z.size() - 2; i >= 0; --i)
      stream << setw(base_digits) << setfill('0') << v.z[i];
    return stream;
  }

  static vector<int> convert_base(const vector<int> &a, int old_digits, int new_digits) {
    vector<long long> p(max(old_digits, new_digits) + 1);
    p[0] = 1;
    for (int i = 1; i < (int)p.size(); i++)
      p[i] = p[i - 1] * 10;
    vector<int> res;
    long long cur = 0;
    int cur_digits = 0;
    for (int i = 0; i < (int)a.size(); i++) {
      cur += a[i] * p[cur_digits];
      cur_digits += old_digits;
      while (cur_digits >= new_digits) {
        res.push_back(int(cur % p[new_digits]));
        cur /= p[new_digits];
        cur_digits -= new_digits;
      }
    }
    res.push_back((int)cur);
    while (!res.empty() && res.back() == 0)
      res.pop_back();
    return res;
  }

  typedef complex<double> MyComplex;

  static void fft(vector<MyComplex> & a, bool invert) {
    int n = (int)a.size();
    if (n == 1)  return;

    vector<MyComplex> a0(n / 2), a1(n / 2);
    for (int i = 0, j = 0; i<n; i += 2, ++j) {
      a0[j] = a[i];
      a1[j] = a[i + 1];
    }
    fft(a0, invert);
    fft(a1, invert);

    double ang = 2 * PI / n * (invert ? -1 : 1);
    MyComplex w(1), wn(cos(ang), sin(ang));
    for (int i = 0; i<n / 2; ++i) {
      a[i] = a0[i] + w * a1[i];
      a[i + n / 2] = a0[i] - w * a1[i];
      if (invert)
        a[i] /= 2, a[i + n / 2] /= 2;
      w *= wn;
    }
  }

  static vector<int> fftMultiply(const vector<int> & a, const vector<int> & b) {
    vector<MyComplex> fa(a.begin(), a.end()), fb(b.begin(), b.end());
    size_t n = 1;
    while (n < max(a.size(), b.size()))  n <<= 1;
    n <<= 1;
    fa.resize(n), fb.resize(n);

    fft(fa, false), fft(fb, false);
    for (size_t i = 0; i<n; ++i)
      fa[i] *= fb[i];
    fft(fa, true);

    vector<int> res(n);
    for (size_t i = 0; i<n; ++i)
      res[i] = int(fa[i].real() + 0.5);

    int carry = 0;
    for (size_t i = 0; i<n; ++i) {
      res[i] += carry;
      carry = res[i] / 100;
      res[i] %= 100;
    }
    while (res.size() > 1 && res.back() == 0)
      res.pop_back();
    return res;
  }

  bigint operator*(const bigint &v) const {
    vector<int> c = fftMultiply(
      convert_base(this->z, base_digits, 2),
      convert_base(v.z, base_digits, 2)
      );
    bigint res;
    res.sign = sign * v.sign;
    res.z = convert_base(c, 2, base_digits);
    res.trim();
    return res;
  }
};

bigint random_bigint(int n) {
  string s;
  for (int i = 0; i < n; i++) {
    s += rnd.next(0, 9) + '0';
  }
  return bigint(s);
}

int main(int argc, char* argv[]) {
  registerGen(argc, argv, 1);

  if (argc != 4) {
    cerr << "Usage: len, mode, seed" << endl;
    return 1;
  }

  int len = atoi(argv[1]);
  int mode = atoi(argv[2]);

  if (mode < 0 || mode > 3) {
    cerr << "Mode should be from 0 to 3" << endl;
    return 2;
  }

  bigint s = random_bigint(len / 2);
  if (mode == 3) {
    // exact square
    cout << s * s << endl;
    return 0;
  }

  if (mode == 1) {
    // exact peak
    cout << s * s + s + 1 << endl;
    return 0;
  }

  bigint r = random_bigint(len / 2);
  if (r > s) {
    bigint tmp = r;
    r = s;
    s = tmp;
  }

  if (mode == 0) {
    // before peak
    cout << s * s + r << endl;
    return 0;
  }

  if (mode == 2) {
    s += 1;
    cout << s * s - r << endl;
    return 0;
  }
}